=================
API Documentation
=================

Reference material for public API.

Core
====

.. toctree::
    :maxdepth: 1

    src/api/gaplic
    src/api/gobj
    src/api/smachine

Essential :term:`gclass`
========================

.. toctree::
    :maxdepth: 1

    src/api/c_timer
    src/api/c_sock
    src/api/c_srv_sock
    src/api/c_connex
